@@ -2,6 +2,7 @@ package MBTest;
 
 use strict;
 
+use IO::File ();
 use File::Spec;
 use File::Temp ();
 use File::Path ();
@@ -11,6 +12,7 @@ use File::Path ();
 BEGIN {
     # Environment variables which might effect our testing
     my @delete_env_keys = qw(
+        HOME
         DEVEL_COVER_OPTIONS
         MODULEBUILDRC
         PERL_MB_OPT
@@ -95,7 +97,11 @@ __PACKAGE__->export(scalar caller, @extra_exports);
 
 # always return to the current directory
 {
-  my $cwd = File::Spec->rel2abs(Cwd::cwd);
+  my $cwd;
+  # must be done in BEGIN because tmpdir uses it in BEGIN for $ENV{HOME}
+  BEGIN { 
+    $cwd = File::Spec->rel2abs(Cwd::cwd);
+  }
 
   sub original_cwd { return $cwd }
 
@@ -108,7 +114,7 @@ __PACKAGE__->export(scalar caller, @extra_exports);
 
 { # backwards compatible temp filename recipe adapted from perlfaq
   my $tmp_count = 0;
-  my $tmp_base_name = sprintf("%d-%d", $$, time());
+  my $tmp_base_name = sprintf("MB-%d-%d", $$, time());
   sub temp_file_name {
     sprintf("%s-%04d", $tmp_base_name, ++$tmp_count)
   }
@@ -122,9 +128,13 @@ sub tmpdir {
   return File::Temp::tempdir('MB-XXXXXXXX', CLEANUP => 1, DIR => $dir, @args);
 }
 
+BEGIN {
+  $ENV{HOME} = tmpdir; # don't want .modulebuildrc or other things interfering
+}
+
 sub save_handle {
   my ($handle, $subr) = @_;
-  my $outfile = temp_file_name();
+  my $outfile = File::Spec->catfile(File::Spec->tmpdir, temp_file_name());
 
   local *SAVEOUT;
   open SAVEOUT, ">&" . fileno($handle)
@@ -257,5 +267,17 @@ sub timed_out {
   return $saw_alarm;
 }
 
+sub check_EUI {
+  my $timed_out;
+  stdout_stderr_of( sub {
+      $timed_out = timed_out( sub {
+          ExtUtils::Installed->new(extra_libs => [@INC])
+        }
+      );
+    }
+  );
+  return ! $timed_out;
+}
+
 1;
 # vim:ts=2:sw=2:et:sta
